# <Room Name>

<!-- One paragraph: what this room covers and when an agent should read it.
     Be specific — agents use this to decide whether to enter the room. -->
<What this room covers and what queries it answers.>

## Overview

<!-- Key facts, current state, essential numbers. Keep entries terse.
     If a fact changes often, it belongs here. If it's stable, a specialty file. -->

- <Key fact>
- <Key fact>

## <Topic Section>

<!-- Rename this heading to match the domain (e.g. "Cluster Nodes", "API Endpoints").
     Add or remove sections as needed. Each section should have a single clear focus. -->

<Domain-specific content.>

## Key Files

<!-- Canonical paths to important files, configs, or code relevant to this room.
     Only include paths that agents will actually need to reference. -->

| Description | Path |
|---|---|
| <What it is> | `<absolute or repo-relative path>` |

## References

<!-- Required if specialty files exist in this room. One line per file. -->

- [`<specialty-file>.md`](./<specialty-file>.md) — <One-line description of what it contains>

<!--
SIZE LIMIT: Keep this file under 200 lines. When a section grows large,
extract it into a specialty file and add a reference above.

WRITE MODE: This is a canonical file. Edit it explicitly — do not append.
Supersede outdated entries rather than leaving them alongside new ones.
-->
